@@ -12,7 +12,7 @@ def parse_file(path: Path) -> Optional[dt.AnnotationFile]:
         data = json.load(f)
         annotations = list(filter(None, map(_parse_annotation, data["annotations"])))
         annotation_classes = set([annotation.annotation_class for annotation in annotations])
-        return dt.AnnotationFile(path, _remove_leading_slash(data["filename"]), annotation_classes, annotations)
+        return dt.AnnotationFile(path, _remove_leading_slash(data["filename"]), annotation_classes, annotations, remote_path = "/")
 
 
 def _remove_leading_slash(filename):
